==> dde-shell_1.99.32.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_et.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="et">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="159"/>
        <source>Indicator Style</source>
        <translation>Indikaatori stiil</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="161"/>
        <source>Fashion Mode</source>
        <translation>Stiilne režiim</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="166"/>
        <source>Efficient Mode</source>
        <translation>Tugev režiim</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="203"/>
        <source>Left</source>
        <translation>Vasak</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="191"/>
        <source>Position</source>
        <translation>Positsioon</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="172"/>
        <source>Mode</source>
        <translation>Režiim</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="176"/>
        <source>Align Left</source>
        <translation>Vasakule alined</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="178"/>
        <source>Align Top</source>
        <translation>Kaugemale alined</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="185"/>
        <source>Align Center</source>
        <translation>Keskne alineerimine</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="193"/>
        <source>Top</source>
        <translation>Väljapääs</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="198"/>
        <source>Bottom</source>
        <translation>Alaosas</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="208"/>
        <source>Right</source>
        <translation>Parem</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="214"/>
        <source>Status</source>
        <translation>Staatus</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="216"/>
        <source>Keep Shown</source>
        <translation>Jäta nähtavaks</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="221"/>
        <source>Keep Hidden</source>
        <translation>Jäta piisavalt</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="226"/>
        <source>Smart Hide</source>
        <translation>Intelliنتجنتи尔隐藏</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="233"/>
        <source>Dock Settings</source>
        <translation>Peidete seaded</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_et.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="et">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Indikaatori stiil</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Stiilne režiim</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Tugev režiim</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Klassikaline režiim</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Keskmistamine režiim</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vasak</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Positsioon</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Režiim</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Väljapääs</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Alaosas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Parem</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Staatus</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Jäta nähtavaks</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Jäta piisavalt</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Intelliنتجنتи尔隐藏</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Peidete seaded</translation>
    </message>
</context>
</TS>
